@@ -4,18 +4,19 @@ To run in CLI mode.
 """
 from pygeoweaver import detail_host, detail_process, detail_workflow, export_workflow, \
     show_history, import_workflow, list_hosts, list_processes, list_workflows, \
-    start, stop, reset_password, run_process, run_worklfow, helpwith, ui
+    start, stop, reset_password, run_process, run_worklfow, helpwith
 from pygeoweaver.server import show
 
+
 def main():
     # start geoweaver
-    # start()
+    start()
     # stop geoweaver
     # stop()
     # list resources
-    #list_hosts()
-    #list_processes()
-    # list_workflows()
+    list_hosts()
+    list_processes()
+    list_workflows()
     # show history
     #show_history("ll3u3W78eOEfklxhBJ")
     # detail host
@@ -38,8 +39,9 @@ def main():
 
     # reset localhost password for Geoweaver
     # reset_password()
-    show()
+    # show()
     # helpwith()
+    # check_java()
 
 
 if __name__ == "__main__":
