@@ -3,14 +3,14 @@ Detail subcommand
 """
 
 import subprocess
-from pygeoweaver.utils import download_geoweaver_jar, get_geoweaver_jar_path, get_root_dir
+from pygeoweaver.utils import download_geoweaver_jar, get_geoweaver_jar_path, get_java_bin_path, get_root_dir
 
 
 def detail_workflow(workflow_id):
     if not workflow_id:
         raise RuntimeError("Workflow id is missing")
     download_geoweaver_jar()
-    subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "detail", f"--workflow-id={workflow_id}"], 
+    subprocess.run([get_java_bin_path(), "-jar", get_geoweaver_jar_path(), "detail", f"--workflow-id={workflow_id}"], 
                    cwd=f"{get_root_dir()}/")
 
 
@@ -18,12 +18,12 @@ def detail_process(process_id):
     if not process_id:
         raise RuntimeError("Process id is missing")
     download_geoweaver_jar()
-    subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "detail", f"--process-id={process_id}"], 
+    subprocess.run([get_java_bin_path(), "-jar", get_geoweaver_jar_path(), "detail", f"--process-id={process_id}"], 
                    cwd=f"{get_root_dir()}/")
 
 def detail_host(host_id):
     if not host_id:
         raise RuntimeError("Host id is missing")
     download_geoweaver_jar()
-    subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "detail", f"--host-id={host_id}"], 
+    subprocess.run([get_java_bin_path(), "-jar", get_geoweaver_jar_path(), "detail", f"--host-id={host_id}"], 
                    cwd=f"{get_root_dir()}/")
\ No newline at end of file
