@@ -2,7 +2,9 @@ import os
 import subprocess
 import webbrowser
 from pygeoweaver.constants import GEOWEAVER_DEFAULT_ENDPOINT_URL
-from pygeoweaver.utils import checkIPython, checkOS, download_geoweaver_jar, get_logger, get_module_absolute_path, get_root_dir
+from pygeoweaver.jdk_utils import check_java
+from pygeoweaver.utils import check_ipython, check_os, download_geoweaver_jar, get_logger, get_module_absolute_path, \
+    get_root_dir
 
 """
 This module provides function to start and stop Geoweaver server.
@@ -13,30 +15,32 @@ open Geoweaver GUI in the output cell (if gui is not disabld.)
 
 logger = get_logger(__name__)
 
+
 def start(force=False):
     download_geoweaver_jar(overwrite=force)
-    if checkOS() == 3:
-        raise RuntimeError("windows is not supported yet")
+    check_java()
+
+    if check_os() == 3:
+        subprocess.run([f'{get_module_absolute_path()}/start.bat'], cwd=f"{get_root_dir()}/")
     else:
-        result = subprocess.run([f'{get_module_absolute_path()}/start.sh'], cwd=f"{get_root_dir()}/")
-    
+        subprocess.run([f'{get_module_absolute_path()}/start.sh'], cwd=f"{get_root_dir()}/")
 
 
 def stop():
-    if checkOS() == 3:
-        raise RuntimeError("Windows is not supported yet")
+    check_java()
+    if check_os() == 3:
+        subprocess.run([f'{get_module_absolute_path()}/stop.bat'], cwd=f"{get_root_dir()}/", shell=True)
     else:
-        result = subprocess.run([f'{get_module_absolute_path()}/stop.sh'], cwd=f"{get_root_dir()}/", shell=True)
-    
+        subprocess.run([f'{get_module_absolute_path()}/stop.sh'], cwd=f"{get_root_dir()}/", shell=True)
 
-def show(geoweaver_url = GEOWEAVER_DEFAULT_ENDPOINT_URL):
+
+def show(geoweaver_url=GEOWEAVER_DEFAULT_ENDPOINT_URL):
     download_geoweaver_jar()  # check if geoweaver is initialized
-    if checkIPython():
+    check_java()
+    if check_ipython():
         logger.info("enter ipython block")
         from IPython.display import IFrame
         return IFrame(src=geoweaver_url, width='100%', height='500px')
     else:
         logger.info("enter self opening block")
         webbrowser.open(geoweaver_url)
-
-
